import _extends from "@babel/runtime/helpers/extends";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import DualListSelectCommon from '@data-driven-forms/common/dual-list-select';
import Button from "semantic-ui-react/dist/es/elements/Button/Button.js";
import Grid from "semantic-ui-react/dist/es/collections/Grid/Grid.js";
import GridColumn from "semantic-ui-react/dist/es/collections/Grid/GridColumn.js";
import Input from "semantic-ui-react/dist/es/elements/Input/Input.js";
import Segment from "semantic-ui-react/dist/es/elements/Segment/Segment.js";
import Header from "semantic-ui-react/dist/es/elements/Header/Header.js";
import FormField from '../form-field';
import createUseStyles from "react-jss/dist/react-jss.esm.js";
import clsx from 'clsx';
import FormFieldGrid from '../form-field-grid';
import { validationError, validationWarning } from '../helpers/helpers';
var useListStyles = createUseStyles({
  root: {
    padding: '.25em'
  },
  selected: {
    color: 'white',
    background: '#2185d0'
  }
});

var List = function List(_ref) {
  var value = _ref.value,
      optionClick = _ref.optionClick,
      noOptionsTitle = _ref.noOptionsTitle,
      filterValue = _ref.filterValue,
      filterValueText = _ref.filterValueText,
      selectedValues = _ref.selectedValues,
      _ref$OptionProps = _ref.OptionProps,
      className = _ref$OptionProps.className,
      selectedClassName = _ref$OptionProps.selectedClassName,
      OptionProps = _objectWithoutProperties(_ref$OptionProps, ["className", "selectedClassName"]),
      rest = _objectWithoutProperties(_ref, ["value", "optionClick", "noOptionsTitle", "filterValue", "filterValueText", "selectedValues", "OptionProps"]);

  var classes = useListStyles();
  return /*#__PURE__*/React.createElement(Segment, rest, value.length < 1 && /*#__PURE__*/React.createElement("div", null, filterValue ? filterValueText : noOptionsTitle), value.length > 0 && value.map(function (_ref2) {
    var _clsx;

    var value = _ref2.value,
        label = _ref2.label;
    return /*#__PURE__*/React.createElement("div", _extends({
      className: clsx(classes.root, className, (_clsx = {}, _defineProperty(_clsx, classes.selected, selectedValues.includes(value)), _defineProperty(_clsx, selectedClassName, selectedValues.includes(value)), _clsx))
    }, OptionProps, {
      onClick: function onClick(e) {
        return optionClick(e, value);
      },
      key: value,
      value: value
    }), label);
  }));
};

List.propTypes = {
  value: PropTypes.arrayOf(PropTypes.shape({
    value: PropTypes.string.isRequired,
    label: PropTypes.string.isRequired
  })),
  optionClick: PropTypes.func.isRequired,
  noOptionsTitle: PropTypes.node,
  filterValue: PropTypes.string,
  filterValueText: PropTypes.node,
  selectedValues: PropTypes.array,
  OptionProps: PropTypes.shape({
    className: PropTypes.string,
    selectedClassName: PropTypes.string
  })
};
List.defaultProps = {
  value: [],
  OptionProps: {}
};

var Toolbar = function Toolbar(_ref3) {
  var sortTitle = _ref3.sortTitle,
      onFilter = _ref3.onFilter,
      onSort = _ref3.onSort,
      sortDirection = _ref3.sortDirection,
      value = _ref3.value,
      placeholder = _ref3.placeholder,
      id = _ref3.id,
      sortUpIcon = _ref3.sortUpIcon,
      sortDownIcon = _ref3.sortDownIcon,
      rest = _objectWithoutProperties(_ref3, ["sortTitle", "onFilter", "onSort", "sortDirection", "value", "placeholder", "id", "sortUpIcon", "sortDownIcon"]);

  return /*#__PURE__*/React.createElement("div", {
    id: id
  }, /*#__PURE__*/React.createElement(Input, _extends({
    name: "filterOptions",
    id: "filterOptions",
    type: "search",
    icon: "search",
    iconPosition: "left",
    "aria-label": placeholder,
    onChange: function onChange(_ref4) {
      var value = _ref4.target.value;
      return onFilter(value);
    },
    placeholder: placeholder,
    action: /*#__PURE__*/React.createElement(Button, {
      type: "button",
      onClick: onSort,
      title: sortTitle,
      icon: sortDirection ? sortUpIcon : sortDownIcon
    })
  }, rest)));
};

Toolbar.propTypes = {
  sortTitle: PropTypes.node,
  onFilter: PropTypes.func.isRequired,
  onSort: PropTypes.func.isRequired,
  sortDirection: PropTypes.bool,
  value: PropTypes.string,
  placeholder: PropTypes.string,
  id: PropTypes.string,
  sortUpIcon: PropTypes.string,
  sortDownIcon: PropTypes.string
};
Toolbar.defaultProps = {
  sortUpIcon: 'sort amount up',
  sortDownIcon: 'sort amount down'
};
var useDualListStyles = createUseStyles({
  dualListButtons: {
    display: 'flex !important',
    alignItems: 'flex-start',
    justifyContent: 'center'
  },
  transferButton: {
    display: 'block !important',
    margin: 'auto !important'
  },
  formField: {
    '&>label': {
      display: 'inline-block !important'
    }
  },
  '@media screen and (max-width: 767px)': {
    transferButton: {
      transform: 'rotate(90deg)'
    }
  }
});

var DualList = function DualList(_ref5) {
  var meta = _ref5.meta,
      input = _ref5.input,
      allToRight = _ref5.allToRight,
      allToLeft = _ref5.allToLeft,
      leftTitle = _ref5.leftTitle,
      moveAllLeftTitle = _ref5.moveAllLeftTitle,
      moveAllRightTitle = _ref5.moveAllRightTitle,
      moveRightTitle = _ref5.moveRightTitle,
      moveLeftTitle = _ref5.moveLeftTitle,
      rightTitle = _ref5.rightTitle,
      label = _ref5.label,
      isRequired = _ref5.isRequired,
      helperText = _ref5.helperText,
      noValueTitle = _ref5.noValueTitle,
      noOptionsTitle = _ref5.noOptionsTitle,
      filterOptionsTitle = _ref5.filterOptionsTitle,
      filterValueTitle = _ref5.filterValueTitle,
      filterValueText = _ref5.filterValueText,
      filterOptionsText = _ref5.filterOptionsText,
      state = _ref5.state,
      id = _ref5.id,
      sortOptions = _ref5.sortOptions,
      filterOptions = _ref5.filterOptions,
      handleOptionsClick = _ref5.handleOptionsClick,
      leftValues = _ref5.leftValues,
      handleMoveRight = _ref5.handleMoveRight,
      handleMoveLeft = _ref5.handleMoveLeft,
      handleClearLeftValues = _ref5.handleClearLeftValues,
      handleClearRightValues = _ref5.handleClearRightValues,
      sortValues = _ref5.sortValues,
      filterValues = _ref5.filterValues,
      rightValues = _ref5.rightValues,
      handleValuesClick = _ref5.handleValuesClick,
      validateOnMount = _ref5.validateOnMount,
      OptionsListProps = _ref5.OptionsListProps,
      OptionProps = _ref5.OptionProps,
      _ref5$LabelProps = _ref5.LabelProps,
      labelClassName = _ref5$LabelProps.className,
      labelError = _ref5$LabelProps.error,
      LabelProps = _objectWithoutProperties(_ref5$LabelProps, ["className", "error"]),
      ToolbarProps = _ref5.ToolbarProps,
      _ref5$ButtonGridProps = _ref5.ButtonGridProps,
      buttonGridClassName = _ref5$ButtonGridProps.className,
      ButtonGridProps = _objectWithoutProperties(_ref5$ButtonGridProps, ["className"]),
      RightButtonProps = _ref5.RightButtonProps,
      DoubleRightButtonProps = _ref5.DoubleRightButtonProps,
      LeftButtonProps = _ref5.LeftButtonProps,
      DoubleLeftButtonProps = _ref5.DoubleLeftButtonProps,
      OptionsHeaderProps = _ref5.OptionsHeaderProps,
      ValuesHeaderProps = _ref5.ValuesHeaderProps,
      HelperTextProps = _ref5.HelperTextProps,
      FormFieldGridProps = _ref5.FormFieldGridProps;

  var invalid = validationError(meta, validateOnMount);
  var classes = useDualListStyles();
  return /*#__PURE__*/React.createElement(FormFieldGrid, _extends({
    helperText: validationWarning(meta, validateOnMount) || helperText,
    HelperTextProps: HelperTextProps
  }, FormFieldGridProps), /*#__PURE__*/React.createElement(FormField, _extends({
    label: label,
    required: isRequired,
    error: invalid && _objectSpread({
      content: meta.error || meta.submitError,
      pointing: 'left'
    }, labelError),
    id: id || input.name,
    control: function control(props) {
      return null;
    }
  }, LabelProps, {
    className: clsx(classes.formField, labelClassName)
  })), /*#__PURE__*/React.createElement(Grid, {
    key: "0"
  }, /*#__PURE__*/React.createElement(GridColumn, {
    mobile: 16,
    tablet: 7,
    computer: 7
  }, /*#__PURE__*/React.createElement(Grid, null, /*#__PURE__*/React.createElement(GridColumn, {
    mobile: 16,
    tablet: 16
  }, /*#__PURE__*/React.createElement(Header, _extends({
    sub: true
  }, OptionsHeaderProps), leftTitle)), /*#__PURE__*/React.createElement(GridColumn, {
    mobile: 16,
    tablet: 16
  }, /*#__PURE__*/React.createElement(Toolbar, _extends({
    sortDirection: state.sortLeftDesc,
    onSort: sortOptions,
    onFilter: filterOptions,
    value: state.filterOptions,
    placeholder: filterOptionsTitle,
    id: "".concat(input.name, "-options-toolbar")
  }, ToolbarProps))), /*#__PURE__*/React.createElement(GridColumn, {
    mobile: 16,
    tablet: 16
  }, /*#__PURE__*/React.createElement(List, _extends({}, OptionsListProps, {
    OptionProps: OptionProps,
    optionClick: handleOptionsClick,
    value: leftValues,
    noOptionsTitle: noOptionsTitle,
    filterValue: state.filterOptions,
    filterValueText: filterOptionsText,
    selectedValues: state.selectedLeftValues
  }))))), /*#__PURE__*/React.createElement(GridColumn, _extends({
    className: clsx(classes.dualListButtons, buttonGridClassName)
  }, ButtonGridProps, {
    mobile: 16,
    tablet: 2,
    computer: 2
  }), /*#__PURE__*/React.createElement(Grid, null, /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16,
    mobile: 4
  }, /*#__PURE__*/React.createElement(Button, _extends({
    className: classes.transferButton,
    icon: "angle right"
  }, RightButtonProps, {
    type: "button",
    disabled: leftValues.length === 0,
    onClick: handleMoveRight,
    title: moveRightTitle
  }))), allToRight && /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16,
    mobile: 4
  }, /*#__PURE__*/React.createElement(Button, _extends({
    className: classes.transferButton,
    icon: "angle double right"
  }, DoubleRightButtonProps, {
    type: "button",
    disabled: leftValues.length === 0,
    onClick: handleClearLeftValues,
    title: moveAllRightTitle
  }))), allToLeft && /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16,
    mobile: 4
  }, /*#__PURE__*/React.createElement(Button, _extends({
    className: classes.transferButton,
    icon: "angle double left"
  }, LeftButtonProps, {
    type: "button",
    disabled: rightValues.length === 0,
    onClick: handleClearRightValues,
    title: moveAllLeftTitle
  }))), /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16,
    mobile: 4
  }, /*#__PURE__*/React.createElement(Button, _extends({
    className: classes.transferButton,
    icon: "angle left"
  }, DoubleLeftButtonProps, {
    type: "button",
    disabled: rightValues.length === 0,
    onClick: handleMoveLeft,
    title: moveLeftTitle
  }))))), /*#__PURE__*/React.createElement(GridColumn, {
    mobile: 16,
    tablet: 7,
    computer: 7
  }, /*#__PURE__*/React.createElement(Grid, null, /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16
  }, /*#__PURE__*/React.createElement(Header, _extends({
    sub: true
  }, ValuesHeaderProps), rightTitle)), /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16
  }, /*#__PURE__*/React.createElement(Toolbar, _extends({
    sortDirection: state.sortRightDesc,
    onSort: sortValues,
    onFilter: filterValues,
    value: state.filterValue,
    placeholder: filterValueTitle,
    id: "".concat(input.name, "-value-toolbar")
  }, ToolbarProps))), /*#__PURE__*/React.createElement(GridColumn, {
    tablet: 16
  }, /*#__PURE__*/React.createElement(List, _extends({}, OptionsListProps, {
    OptionProps: OptionProps,
    optionClick: handleValuesClick,
    value: rightValues,
    noOptionsTitle: noValueTitle,
    filterValue: state.filterValue,
    filterValueText: filterValueText,
    selectedValues: state.selectedRightValues
  })))))));
};

DualList.propTypes = {
  leftTitle: PropTypes.node,
  rightTitle: PropTypes.node,
  moveLeftTitle: PropTypes.node,
  moveRightTitle: PropTypes.node,
  allToLeft: PropTypes.bool,
  allToRight: PropTypes.bool,
  moveAllLeftTitle: PropTypes.node,
  moveAllRightTitle: PropTypes.node,
  label: PropTypes.node,
  isRequired: PropTypes.bool,
  helperText: PropTypes.node,
  noValueTitle: PropTypes.node,
  noOptionsTitle: PropTypes.node,
  filterOptionsTitle: PropTypes.node,
  filterValueTitle: PropTypes.node,
  filterValueText: PropTypes.node,
  filterOptionsText: PropTypes.node,
  id: PropTypes.string,
  input: PropTypes.shape({
    name: PropTypes.string.isRequired
  }),
  meta: PropTypes.any,
  state: PropTypes.object,
  sortOptions: PropTypes.func,
  filterOptions: PropTypes.func,
  handleOptionsClick: PropTypes.func,
  leftValues: PropTypes.array,
  handleMoveRight: PropTypes.func,
  handleMoveLeft: PropTypes.func,
  handleClearLeftValues: PropTypes.func,
  handleClearRightValues: PropTypes.func,
  sortValues: PropTypes.func,
  filterValues: PropTypes.func,
  rightValues: PropTypes.array,
  handleValuesClick: PropTypes.func,
  validateOnMount: PropTypes.bool,

  /** Sub components customization API */
  OptionsListProps: PropTypes.object,
  OptionProps: PropTypes.object,
  LabelProps: PropTypes.shape({
    error: PropTypes.object,
    className: PropTypes.string
  }),
  ToolbarProps: PropTypes.object,
  ButtonGridProps: PropTypes.shape({
    className: PropTypes.string
  }),
  RightButtonProps: PropTypes.object,
  DoubleRightButtonProps: PropTypes.object,
  LeftButtonProps: PropTypes.object,
  DoubleLeftButtonProps: PropTypes.object,
  OptionsHeaderProps: PropTypes.object,
  ValuesHeaderProps: PropTypes.object,
  HelperTextProps: PropTypes.object,
  FormFieldGridProps: PropTypes.object
};
DualList.defaultProps = {
  leftTitle: 'Options',
  rightTitle: 'Selected',
  moveLeftTitle: 'Move selected to left',
  moveRightTitle: 'Move selected to right',
  moveAllRightTitle: 'Move all to right',
  moveAllLeftTitle: 'Move all to left',
  noOptionsTitle: 'No available options',
  noValueTitle: 'No selected',
  filterOptionsTitle: 'Filter options',
  filterValueTitle: 'Filter selected value',
  filterOptionsText: 'Remove your filter to see all options',
  filterValueText: 'Remove your filter to see all selected',
  options: [],
  allToLeft: true,
  allToRight: true,
  OptionsListProps: {},
  OptionProps: {},
  LabelProps: {},
  ToolbarProps: {},
  ButtonGridProps: {},
  RightButtonProps: {},
  DoubleRightButtonProps: {},
  LeftButtonProps: {},
  DoubleLeftButtonProps: {},
  OptionsHeaderProps: {},
  ValuesHeaderProps: {},
  HelperTextProps: {},
  FormFieldGridProps: {}
};

var DualListSelectWrapper = function DualListSelectWrapper(props) {
  return /*#__PURE__*/React.createElement(DualListSelectCommon, _extends({}, props, {
    DualListSelect: DualList
  }));
};

export default DualListSelectWrapper;